@@ -27,7 +27,7 @@
 
 #ifdef	HAVE_CONFIG_H
 #include <config.h>
-#endif	/* !HAVE_CONFIG_H */
+#endif /* !HAVE_CONFIG_H */
 
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -54,21 +54,21 @@ extern void mainwin_setup (void);
 GList *printers_list;
 
 int
-main(int argc, char **argv)
+main (int argc, char **argv)
 {
   char **nargv;
   McsClient *client;
   Display *dpy;
   int screen;
 
-  if (argc > 1  && !(!strcmp (argv[1], "--version") || !strcmp(argv[1], "-V"))) {
-    nargv = malloc((argc + 1) * sizeof(char *));
-    memcpy(nargv, argv, argc * sizeof(char *));
+  if (argc > 1 && !(!strcmp (argv[1], "--version") || !strcmp (argv[1], "-V"))) {
+    nargv = malloc ((argc + 1) * sizeof (char *));
+    memcpy (nargv, argv, argc * sizeof (char *));
     nargv[0] = "xfprint4";
     nargv[argc] = NULL;
-    execvp("xfprint4", nargv);
-    xfce_err(_("Unable to execute xfprint4"));
-    exit(127);
+    execvp ("xfprint4", nargv);
+    xfce_err (_("Unable to execute xfprint4"));
+    exit (127);
   }
 
 #if 0
@@ -82,37 +82,38 @@ main(int argc, char **argv)
 #endif
 #else
   /* This is required for UTF-8 at least - Please don't remove it */
-  xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+  xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 #endif
 
   gtk_set_locale ();
-  gtk_init(&argc, &argv);
+  gtk_init (&argc, &argv);
 
   /* Load the printing system module */
   dpy = GDK_DISPLAY ();
   screen = XDefaultScreen (dpy);
-	
-  if(!mcs_client_check_manager (dpy, screen, "xfce-mcs-manager"))
+
+  if (!mcs_client_check_manager (dpy, screen, "xfce-mcs-manager"))
     g_warning ("%s: mcs manager not running\n", PACKAGE);
   client = mcs_client_new (dpy, screen, NULL, NULL, NULL);
-  if(client){
+  if (client) {
     McsSetting *setting;
 
     mcs_client_add_channel (client, CHANNEL);
 
-    if( mcs_client_get_setting (client, "XfPrint/system", CHANNEL, &setting) == MCS_SUCCESS){
+    if (mcs_client_get_setting (client, "XfPrint/system", CHANNEL, &setting) == MCS_SUCCESS) {
       if (!load_printing_system (setting->data.v_string))
-	g_error ("Unable to load printing system module %s", setting->data.v_string);
+        g_error ("Unable to load printing system module %s", setting->data.v_string);
       mcs_setting_free (setting);
-    }else{
+    }
+    else {
       gchar *default_system = NULL;
 
       g_warning ("No mcs-setting found for XfPrint/system in channel %s, using default printing-system", CHANNEL);
 
       default_system = g_build_filename (PLUGIN_DIR, "file_plugin.so", NULL);
 
-      if (!load_printing_system (default_system)){
-	g_error ("Unable to load default printing system module %s", default_system);
+      if (!load_printing_system (default_system)) {
+        g_error ("Unable to load default printing system module %s", default_system);
       }
 
       g_free (default_system);
@@ -121,23 +122,20 @@ main(int argc, char **argv)
     mcs_client_destroy (client);
   }
 
-  if (argc > 1 && (!strcmp (argv[1], "--version") || !strcmp(argv[1], "-V"))){
+  if (argc > 1 && (!strcmp (argv[1], "--version") || !strcmp (argv[1], "-V"))) {
     PrintingSystemInfo *psinfo;
 
     psinfo = g_new0 (PrintingSystemInfo, 1);
 
     printing_system_info_init (psinfo);
 
-    g_print ("\tThis is %s-manager version %s for Xfce %s\n", PACKAGE, VERSION,
-	     xfce_version_string());
-    g_print ("\tbuilt with GTK+-%d.%d.%d, ", GTK_MAJOR_VERSION,
-	     GTK_MINOR_VERSION, GTK_MICRO_VERSION);
-    g_print ("linked with GTK+-%d.%d.%d.\n", gtk_major_version,
-	     gtk_minor_version, gtk_micro_version);
+    g_print ("\tThis is %s-manager version %s for Xfce %s\n", PACKAGE, VERSION, xfce_version_string ());
+    g_print ("\tbuilt with GTK+-%d.%d.%d, ", GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION);
+    g_print ("linked with GTK+-%d.%d.%d.\n", gtk_major_version, gtk_minor_version, gtk_micro_version);
     g_print ("\tCurrently it uses the %s printing system.\n", psinfo->name);
-    
+
     printing_system_info_free (psinfo);
-    exit(EXIT_SUCCESS);
+    exit (EXIT_SUCCESS);
   }
 
 
@@ -145,14 +143,13 @@ main(int argc, char **argv)
   /* Initialize printers list */
   printers_list = printing_system_get_printers_list ();
 
-  mainwin_setup();
+  mainwin_setup ();
 
-  gtk_main();
+  gtk_main ();
 
   /* Free dynamicly allocated memory */
-  g_list_foreach (printers_list, (GFunc)printer_free, NULL);
+  g_list_foreach (printers_list, (GFunc) printer_free, NULL);
   g_list_free (printers_list);
 
-  return(0);
+  return (0);
 }
-
