@@ -121,6 +121,7 @@ mainwin_setup (void)
   GtkCellRenderer *icon_cell;
   GtkCellRenderer *alias_cell;
   GtkTreeViewColumn *alias_column;
+  GdkPixbuf *icon = NULL;
 
   dlg = g_new0 (ManagerDlg, 1);
 
@@ -130,7 +131,12 @@ mainwin_setup (void)
   g_signal_connect (G_OBJECT (dlg->icontheme), "changed", G_CALLBACK (icon_theme_changed_cb), dlg);
 
   dlg->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_icon (GTK_WINDOW (dlg->window), xfce_icon_theme_load (dlg->icontheme, "xfprint", 48));
+  icon = xfce_icon_theme_load (dlg->icontheme, "xfprint", 48);
+  if (icon) {
+    gtk_window_set_icon (GTK_WINDOW (dlg->window), xfce_icon_theme_load (dlg->icontheme, "xfprint", 48));
+    g_object_unref (icon);
+  }
+
   gtk_window_add_accel_group (GTK_WINDOW (dlg->window), dlg->accel_group);
   gtk_window_set_default_size (GTK_WINDOW (dlg->window), 450, 250);
   gtk_window_set_title (GTK_WINDOW (dlg->window), _("Printer manager"));
